# lens\_csv

A [lens](https://github.com/port-zero/lens) plugin for CSV.

It is rather boring, as it only accepts row and column indices.

## Installation

```
pip install lens_csv
```

## Usage

The plugin will be picked up by lens immediately as a format.
There is nothing you need to do for it to work.

<hr/>

Have fun!
